@@ -1,9 +1,9 @@
 working.ltsk <-
-function(q0,obs,th,vth,vlen,llim,verbose,Large)
+function(q0,obs,th,vth,vlen,llim,verbose,Large,future)
 {
  	## working function for ltsk
 	fit <- rep(0,3)
-	ii <- dnb(q0,obs,th)
+	ii <- dnb(q0,obs,th,future=future)
 	if( length(ii)<=5 ){
 		if(verbose) cat(q0,'k= ',length(ii),'\n')
 		return(c(0,0,4))
@@ -21,16 +21,13 @@ function(q0,obs,th,vth,vlen,llim,verbose,Large)
 		vout <- dvariogram(nbr,vth,vlen)
 		vout <- dsmooth.variogram(vout)
 		fout <- dfitvariogram(vout,nbr)
-		gout <- cal.gamma(q0,nbr,fout)
-		#if(verbose){
-		#	dump.csv(fout,gout)
-		#	tmp <- fout$sill0 - gout$Gamma
-		#	ev <- eigen(tmp,only.value=T)$value
-		#	tmpout[i] <-min(ev)
-		#	cat('minimal eigen value ',round(min(ev),5),'\n')
-		#}
-		fit[1:2] <- with(gout,work.kriging(Gamma,gamma,dat[,4]))
-		fit[3] <- 0 ## sucess
+    if(fout$ret){
+		  gout <- cal.gamma(q0,nbr,fout)
+		  fit[1:2] <- with(gout,work.kriging(Gamma,gamma,dat[,4]))
+		  fit[3] <- 0 ## sucess
+    }else{
+      fit <- c(mean(nbr[,4]),sd(nbr[,4]),4) ## variogram not fit
+    }
 	}else if(ssout$nt <= llim[2]){
 	    if (verbose) cat('insufficient time points.\n')
 		fit <- c(mean(nbr[,4]),sd(nbr[,4]),1)
